# Crewmaster

## Getting Started

```
pip install crewmaster
```

## Variables de entorno

Necesitas crear un archivo .env con las siguientes variables de entorno de openai

```
LLM_API_KEY_OPEN_AI=DEFAULT
LLM_MODEL_OPEN_AI="gpt-3.5-turbo"
LLM_TEMPERATURE_OPEN_AI=0
```